<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Es gibt ein Leben außerhalb des Browsers!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Lizenziert für: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 ist Freie Software, aber die Entwicklung kostet wertvolle Zeit.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Bitte &lt;a href=&apos;%1&apos;&gt;spenden&lt;/a&gt; Sie, um die Weiterentwicklung von %2 zu unterstützen.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Übersetzen Sie %1 in Ihre Muttersprache mit %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icons wurden gestaltet von %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Veröffentlicht unter der &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Geben Sie Ihre Lizenzierungsinformationen ein</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-mail:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Schlüssel:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Bitte lizenzieren Sie %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Diese Demo ist abgelaufen.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Die Vollversion erlaubt es Ihnen, Videos ohne Unterbrechung anzuschauen.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Ohne Lizenz läuft das Programm nur noch %1 Tage.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Mit dem Kauf der Vollversion unterstützen Sie auch die harte Arbeit, die ich in die Erstellung von %1 gesteckt habe.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Demo verwenden</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Lizenzdaten eingeben</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Lizenz kaufen</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Von %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Alle Videos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Ungesehene Videos</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Zuletzt aktualisiert</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Zuletzt hinzugefügt</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Zuletzt angesehen</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Am meisten angesehen</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sortieren nach</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Alle als gesehen markieren</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Zeige aktualisierte</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Du hast keine Abonnements. Benutze das Stern-Symbol, um einen Kanal zu abonnieren.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Alle Videos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Ungesehene Videos</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Als gesehen markieren</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Abonnement beenden</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Zurzeit gibt es nichts Neues bei den Abonnements.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Jetzt</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 mal betrachtet</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>Bytes/s</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>kB/s</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 verbleibend</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 heruntergeladen nach %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Herunterladen abgeschlossen</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Speicherort ändern…</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Wähle den Speicherort</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Speicherort wurde geändert.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Aktuelle Downloads werden immer noch im alten Speicherort gespeichert.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Lade herunter nach: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Die Binärdatei wurde kompromittiert. Möglicherweise von einem Virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 startet nicht. Bitte versuchen Sie eine Neuinstallation.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Verlassen</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Neuinstallation</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Abspielen/Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Halt</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Nach aktuellem Titel Wiedergabe anhalten</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Nächster Titel</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Vorheriger Titel</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Lautstärke erhöhen</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Lautstärke verringern</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stummschalten</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Vorwärts spulen</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Rückwärts spulen</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Videos und Kanäle nach Suchbegriff finden</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Stöbern</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Videos nach Kategorien durchstöbern</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abonnements</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Abonnierte Kanäle</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Machen Sie es sich gemütlich</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenster</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimieren</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Wiedergabe anhalten und zur Suchansicht zurückkehren</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>V&amp;origes</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Zum vorherigen Titel zurückgehen</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Ü&amp;berspringen</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Zum nächsten Video springen</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Abspielen</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Wiedergabe fortsetzen</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Vollbildmodus</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Vollbildmodus aktivieren</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Kompakt-Modus</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Abspielliste und Werkzeugleiste ausblenden</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>&amp;YouTube-Seite öffnen</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Gehe zur YouTube-Video-Seite und pausiere die Wiedergabe</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>YouTube-&amp;Link kopieren</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>YouTube-Link in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Video-Stream-&amp;URL kopieren</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Video-Link in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Suche weitere Video&amp;teile</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Findet andere Teile des Videos, hoffentlich in der richtigen Reihenfolge</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Entfe&amp;rnen</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Entferne das ausgewählte Video aus der Abspielliste</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Bewege &amp;hinauf</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Bewege das ausgewählte Video in der Abspielliste hinauf</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Bewege hin&amp;ab</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Bewege das ausgewählte Video in der Abspielliste hinunter</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>Vorherige Suchbegriffe löschen</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Den Suchverlauf löschen. Kann nicht rückgängig gemacht werden.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Verlassen</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Tschüss</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Webseite</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 im Web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>&amp;Spenden</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Bitte unterstützen Sie die weitere Entwicklung von %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informationen über %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Stummschalten</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Manuelles Starten der Wiedergabe</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Manuelles Starten der Videowiedergabe</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Downloads</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Details über Video-Downloads anzeigen</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>H&amp;erunterladen</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Das aktuelle Video herunterladen</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>&amp;Schnappschuss machen</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Abonnieren des Kanals</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Teilen Sie das aktuellen Video mit %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;E-Mail</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-Mail</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>Im Vordergrund &amp;bleiben</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>Nach diesem Video &amp;anhalten</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Ein Problem melden ...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Suche verfeinern ...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Mehr...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Ve&amp;rwandte Videos</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Verwandte Videos zum Aktuellen ansehen</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Im &amp;Browser öffnen...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>eingeschränkter Modus</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Verstecke Videos die unpassende Inhalte enthalten können</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Gefällt Ihnen %1? Bewertung abgeben!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>%1 kaufen...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Anwendung</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Wiedergabe</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>A&amp;bspielliste</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Teilen</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansehen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>%1 drücken, um die Lautstärke zu erhöhen, %2 um sie zu verringern</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Wähle ein Land für Inhalte</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Öffne %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Möchten Sie %1 mit einem aktiven Download beenden?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Wenn Sie %1 jetzt beenden, wird der Download abgebrochen.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Beenden und Download abbrechen</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Auf Abschluss des Downloads warten</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Fehler: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Wiedergabe pausieren</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Laden</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>&amp;Vollbild verlassen</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Verbleibende Zeit: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Lautstärke %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Ton ist stummgeschaltet</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ton ist eingeschaltet</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maximale Videoauflösung wurde auf %1 gesetzt</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Ihre Privatsphäre ist nun geschützt</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Herunterladen vollständig</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 Version %2 ist jetzt verfügbar.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Erinnere mich später</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualisierung</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Sie können den YouTube-Link nun in einer anderen Anwendung einfügen</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Sie können den Video-Link nun in einer anderen Anwendung einfügen</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Der Link wird nur eine beschränkte Zeit gültig sein.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>%1 herunterladen</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>von </translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>Teil</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>Episode</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Gesendet von %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Beende Abonnement von %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Abonnieren von %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Abonnement von %1 wurde aufgehoben.</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>%1 abonniert</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Eine neue Version von %1 ist verfügbar!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 ist jetzt verfügbar. Sie haben %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Möchten Sie sie jetzt herunterladen?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Diese Version überspringen</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Später erinnern</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Aktualisierung installieren</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 von %2 (%3) – %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Bereite vor</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Fehlgeschlagen</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Fertiggestellt</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Angehalten</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Herunterladen abbrechen</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>In %1 anzeigen</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>übergeordneten Ordner öffnen</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Herunterladen neu starten</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Weitere %1 zeigen</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Keine Videos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Keine weiteren Videos</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sortieren nach</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevanz</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Aufrufe</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Bewertung</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Irgendwann</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Heute</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Tage</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Tage</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Kurz</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Lang</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Weniger als 4 Minuten</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Zwischen 4 und 20 Minuten</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Länger als 20 Minuten</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualität</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Hochauflösend</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p oder höher</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Erledigt</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Willkommen bei &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>um die Wiedergabe zu starten.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>ein Suchbegriff</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Eingeben</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Letzte Suchbegriffe</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Letzte Kanäle</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Die Vollversion kaufen</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zurück</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Weiter zu %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Zurück zu %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Suche verfeinern</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Haben Sie gemeint: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Speicherort ändern…</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Schnappschuss gespeichert unter %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Speicherort der Schnappschüsse geändert.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Beliebteste</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Lade Aktualisierung herunter...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>heruntergeladen %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algerien</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentinien</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australien</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgien</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasilien</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolumbien</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Tschechische Republik</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Ägypten</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Frankreich</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Deutschland</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Griechenland</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Ungarn</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Indien</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesien</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irland</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italien</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japan</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordanien</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenia</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaysia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexiko</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marokko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Niederlande</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Neuseeland</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Philippinen</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polen</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Russland</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saudi-Arabien</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Südafrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Südkorea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spanien</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Schweden</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunesien</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Türkei</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Vereinigte Arabische Emirate</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Vereinigtes Königreich</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Weltweit</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Videostream für %1 konnte nicht geöffnet werden</translation>
    </message>
</context>
</TS>